==> cristalise-xmldb-3.4.0-sources.jar: org/cristalise/storage/xmldb/XMLDBClientReader.java <==
/**
 * This file is part of the CRISTAL-iSE eXist-DB storage plugin.
 * Copyright (c) 2001-2016 The CRISTAL Consortium. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 3 of the License, or (at
 * your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; with out even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
 * License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * http://www.fsf.org/licensing/licenses/lgpl.html
 */
package org.cristalise.storage.xmldb;

import org.cristalise.kernel.common.PersistencyException;
import org.cristalise.kernel.entity.C2KLocalObject;
import org.cristalise.kernel.lookup.ItemPath;

/**
 * 
 */
public class XMLDBClientReader extends XMLDBClusterStorage {

    @Override
    public short queryClusterSupport(String clusterType) {
        return READ;
    }

    @Override
    public String getName() {
        return "XMLDB Client Reader";
    }

    @Override
    public String getId() {
        return "XMLDBClient";
    }

    @Override
    public void put(ItemPath itemPath, C2KLocalObject obj) throws PersistencyException {
        throw new PersistencyException("Writing not supported in XMLDBClientReader");
    }

    @Override
    public void delete(ItemPath itemPath, String path) throws PersistencyException {
        throw new PersistencyException("Writing not supported in XMLDBClientReader");
    }
}

==> cristalise-xmldb-5.3.4-sources.jar: org/cristalise/storage/xmldb/XMLDBClientReader.java <==
/**
 * This file is part of the CRISTAL-iSE eXist-DB storage plugin.
 * Copyright (c) 2001-2016 The CRISTAL Consortium. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 3 of the License, or (at
 * your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; with out even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
 * License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * http://www.fsf.org/licensing/licenses/lgpl.html
 */
package org.cristalise.storage.xmldb;

import org.cristalise.kernel.common.PersistencyException;
import org.cristalise.kernel.entity.C2KLocalObject;
import org.cristalise.kernel.lookup.ItemPath;
import org.cristalise.kernel.persistency.ClusterType;

/**
 * 
 */
public class XMLDBClientReader extends XMLDBClusterStorage {

    @Override
    public short queryClusterSupport(ClusterType clusterType) {
        return READ;
    }

    @Override
    public String getName() {
        return "XMLDB Client Reader";
    }

    @Override
    public String getId() {
        return "XMLDBClient";
    }

    @Override
    public void put(ItemPath itemPath, C2KLocalObject obj, Object transactionKey) throws PersistencyException {
        throw new PersistencyException("Writing not supported in XMLDBClientReader");
    }

    @Override
    public void delete(ItemPath itemPath, String path, Object transactionKey) throws PersistencyException {
        throw new PersistencyException("Writing not supported in XMLDBClientReader");
    }
}
